PresentationAddress

Struct PresentationAddress 

pub struct PresentationAddress {
    pub pSelector: Option<Selector>,
    pub sSelector: Option<Selector>,
    pub tSelector: Option<Selector>,
    pub nAddresses: Vec<Selector>,
}
OSI Presentation Address

This ASN.1-based data structure comes from ITU-T Recommendation X.520.

ASN.1 Definition:

PresentationAddress ::= SEQUENCE {
  pSelector   [0]  OCTET STRING OPTIONAL,
  sSelector   [1]  OCTET STRING OPTIONAL,
  tSelector   [2]  OCTET STRING OPTIONAL,
  nAddresses  [3]  SET SIZE (1..MAX) OF OCTET STRING,
  ... }

Fields

pSelector: Option<Selector>

The P-selector: subaddress for the OSI presentation layer

sSelector: Option<Selector>

The S-selector: subaddress for the OSI session layer

tSelector: Option<Selector>

The T-selector: subaddress for the OSI transport layer

nAddresses: Vec<Selector>

N-addresses: network addresses

Implementations

Source

impl PresentationAddress

pub fn new( pSelector: Option<Selector>, sSelector: Option<Selector>, tSelector: Option<Selector>, nAddresses: Vec<Selector>, ) -> Self

Create a new PresentationAddress

pub fn is_naively_subset_of(&self, other: &Self) -> bool

Returns true if self has the same selectors and a subset of N-addresses of other

Note that the ordering of N-addresses does not matter.

In the naming of this function, the term “naively” is used to mean that N-addresses are compared naively: byte-for-byte. This isn’t totally accurate, since the same underlying network address could be represented in multiple ways in some cases. This is, in part, why PartialEq or Eq is not implemented for PresentationAddress.

pub fn is_naively_exactly(&self, other: &Self) -> bool

Returns true if self has the same selectors and the same N-addresses of other

Note that the ordering of N-addresses does not matter.

In the naming of this function, the term “naively” is used to mean that N-addresses are compared naively: byte-for-byte. This isn’t totally accurate, since the same underlying network address could be represented in multiple ways in some cases. This is, in part, why PartialEq or Eq is not implemented for PresentationAddress.